@@ -45,7 +45,6 @@
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
-#include "xf86Resources.h"
 #include "compiler.h"
 #include "xf86PciInfo.h"
 #include "xf86Pci.h"
@@ -183,7 +182,7 @@ GXInitVideo(ScreenPtr pScrn)
 		adaptors = &newAdaptor;
 	    } else {
 		newAdaptors =	       /* need to free this someplace */
-		    xalloc((num_adaptors +
+		    malloc((num_adaptors +
 			1) * sizeof(XF86VideoAdaptorPtr *));
 		if (newAdaptors) {
 		    memcpy(newAdaptors, adaptors, num_adaptors *
@@ -199,7 +198,7 @@ GXInitVideo(ScreenPtr pScrn)
 	    xf86XVScreenInit(pScrn, adaptors, num_adaptors);
 
 	if (newAdaptors)
-	    xfree(newAdaptors);
+	    free(newAdaptors);
     }
 }
 
@@ -375,7 +374,7 @@ GXSetupImageVideo(ScreenPtr pScrn)
     XF86VideoAdaptorPtr adapt;
     GeodePortPrivRec *pPriv;
 
-    if (!(adapt = xcalloc(1, sizeof(XF86VideoAdaptorRec) +
+    if (!(adapt = calloc(1, sizeof(XF86VideoAdaptorRec) +
 		sizeof(GeodePortPrivRec) + sizeof(DevUnion))))
 	return NULL;
 
@@ -406,7 +405,7 @@ GXSetupImageVideo(ScreenPtr pScrn)
     adapt->QueryImageAttributes = GeodeQueryImageAttributes;
 
     pPriv->filter = 0;
-    pPriv->colorKey = pGeode->videoKey;
+    pPriv->colorKey = 0;
     pPriv->colorKeyMode = 0;
     pPriv->videoStatus = 0;
 #if DBUF
@@ -809,7 +808,7 @@ GXSetVideoPosition(int x, int y, int width, int height,
 
     /* Take care of panning when panel is present */
 
-    startAddress = gfx_get_display_offset() - pGeode->FBOffset;
+    startAddress = gfx_get_display_offset();
     DeltaY = startAddress / pGeode->Pitch;
     DeltaX = startAddress & (pGeode->Pitch - 1);
     DeltaX /= (pScrni->bitsPerPixel >> 3);
@@ -1404,17 +1403,17 @@ GXAllocateSurface(ScrnInfoPtr pScrni,
     surface->width = w;
     surface->height = h;
 
-    if (!(surface->pitches = xalloc(sizeof(int))))
+    if (!(surface->pitches = malloc(sizeof(int))))
 	return BadAlloc;
 
-    if (!(surface->offsets = xalloc(sizeof(int)))) {
-	xfree(surface->pitches);
+    if (!(surface->offsets = malloc(sizeof(int)))) {
+	free(surface->pitches);
 	return BadAlloc;
     }
 
-    if (!(pPriv = xalloc(sizeof(OffscreenPrivRec)))) {
-	xfree(surface->pitches);
-	xfree(surface->offsets);
+    if (!(pPriv = malloc(sizeof(OffscreenPrivRec)))) {
+	free(surface->pitches);
+	free(surface->offsets);
 	return BadAlloc;
     }
 
@@ -1453,9 +1452,9 @@ GXFreeSurface(XF86SurfacePtr surface)
 	GXStopSurface(surface);
 
     xf86FreeOffscreenArea(pPriv->area);
-    xfree(surface->pitches);
-    xfree(surface->offsets);
-    xfree(surface->devPrivate.ptr);
+    free(surface->pitches);
+    free(surface->offsets);
+    free(surface->devPrivate.ptr);
 
     return Success;
 }
@@ -1543,7 +1542,7 @@ GXInitOffscreenImages(ScreenPtr pScrn)
     XF86OffscreenImagePtr offscreenImages;
 
     /* need to free this someplace */
-    if (!(offscreenImages = xalloc(sizeof(XF86OffscreenImageRec))))
+    if (!(offscreenImages = malloc(sizeof(XF86OffscreenImageRec))))
 	return;
 
     offscreenImages[0].image = &Images[0];
